// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
/* exported init buildPrefsWidget */

const { Gio, GLib, GObject, Gtk } = imports.gi;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

const Gettext = imports.gettext.domain(Me.metadata['gettext-domain']);
const _ = Gettext.gettext;

/** */
function init() {
    ExtensionUtils.initTranslations();
}

const MoveNotificationsPrefsWidget = GObject.registerClass(
class MoveNotificationsPrefsWidget extends Gtk.Box {
    _init() {
        super._init({
            orientation: Gtk.Orientation.VERTICAL,
            spacing: 6,
            margin_top: 36,
            margin_bottom: 36,
            margin_start: 36,
            margin_end: 36,
            halign: Gtk.Align.CENTER,
        });

        this._actionGroup = new Gio.SimpleActionGroup();
        this.insert_action_group('move-notifications', this._actionGroup);

        this._settings = ExtensionUtils.getSettings();
        this._actionGroup.add_action(
            this._settings.create_action('position'));

        const title = new Gtk.Label({
            label: _('Notification Position'),
            halign: Gtk.Align.START,
        });
        title.add_css_class('heading');
        this.append(title);

        const box = new Gtk.Box({
            orientation: Gtk.Orientation.VERTICAL,
            spacing: 12,
            margin_bottom: 12,
        });
        this.append(box);

        const context = box.get_style_context();
        const cssProvider = new Gtk.CssProvider();
        cssProvider.load_from_data(
            'box { padding: 12px; }', -1);

        context.add_provider(cssProvider,
            Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION);
        context.add_class('boxed-list');
        context.add_class('view');

        const positions = [
            { pos: 'top-right', label: _('Top–Right') },
            { pos: 'top-center', label: _('Top–Center') },
            { pos: 'top-left', label: _('Top–Left') },
        ];
        let group = null;
        for (const { pos, label } of positions) {
            const check = new Gtk.CheckButton({
                action_name: 'move-notifications.position',
                action_target: new GLib.Variant('s', pos),
                label,
                group,
                margin_end: 12,
            });
            group = check;
            box.append(check);
        }
    }
});

/**
 * @returns {Gtk.Widget} - the prefs widget
 */
function buildPrefsWidget() {
    return new MoveNotificationsPrefsWidget();
}
